Clazz.declarePackage("J.quantum");
Clazz.load(["J.quantum.QuantumCalculation"], "J.quantum.QuantumPlaneCalculation", null, function(){
var c$ = Clazz.declareType(J.quantum, "QuantumPlaneCalculation", J.quantum.QuantumCalculation);
});
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
